method_to_pascal

Function method_to_pascal 

pub fn method_to_pascal(method: &str) -> String
PascalCase derived from a /- and _-delimited method name, e.g. "thread/start" -> "ThreadStart". Only the first character of each segment is uppercased; the rest of the segment is left untouched (so already-camelCase segments like "mcpServer" become "McpServer", not "MCPSERVER" or "Mcpserver").